@@ -76,7 +76,7 @@ class CoffeeScriptMiddleware(object):
         none_match = environment.get('HTTP_IF_NONE_MATCH')
 
         if none_match and etag_key == none_match:
-            start_response('304 Not Modified', (('ETag', etag_key),))
+            start_response('304 Not Modified', [('ETag', etag_key)])
             return ['']
 
         try:
